==> spip_4.0.4.orig.tar.xz: ecrire/lang/public_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'ホーム',
	'article' => '記事',
	'articles' => '記事',
	'articles_auteur' => 'この著者の記事',
	'articles_populaires' => '人気のある記事',
	'articles_rubrique' => 'このセクションにある記事',
	'aucun_article' => 'このアドレスに記事はありません',
	'aucun_auteur' => 'このアドレスに著者はいません',
	'aucun_site' => 'このアドレスにサイトはありません',
	'aucune_breve' => 'このアドレスにニュースはありません',
	'aucune_rubrique' => 'このアドレスにセクションはありません',
	'auteur' => '著者',
	'autres' => 'その他',
	'autres_breves' => '他のニュース',
	'autres_groupes_mots_clefs' => 'キーワードの他のグループ',
	'autres_sites' => '他のサイト',

	// B
	'bonjour' => 'こんにちは',

	// C
	'commenter_site' => 'このサイトについてコメントして下さい',
	'contact' => '連絡先',
	'copie_document_impossible' => 'ファイルのコーピは不可能です',

	// D
	'date' => '日付',
	'dernier_ajout' => '最新の追加',
	'dernieres_breves' => '最新のニュース',
	'derniers_articles' => '最新の記事',
	'derniers_commentaires' => '最新のコメント',
	'derniers_messages_forum' => 'フォーラムで投稿された最新のメッセージ',

	// E
	'edition_mode_texte' => 'テキストモード編集',
	'en_reponse' => '返事として：',
	'en_resume' => 'まとめとして',
	'envoyer_message' => 'メッセージを送る',
	'espace_prive' => '管理エリア',

	// F
	'formats_acceptes' => '受け入れるファイルのフォーマット: @formats@です。',

	// H
	'hierarchie_site' => 'サイトの階層',

	// J
	'jours' => '日付',

	// L
	'lien_connecter' => 'ログイン',

	// M
	'meme_auteur' => '同じ著者',
	'meme_rubrique' => '同じセクションの中で',
	'memes_auteurs' => '同じ著者',
	'message' => 'フォーラムのメッセージ',
	'messages_forum' => 'フォーラムのメッセージ',
	'messages_recents' => '最新のフォーラムのメッセージ',
	'mots_clef' => 'キーワード',
	'mots_clefs' => 'キーワード',
	'mots_clefs_meme_groupe' => '同じグループのキーワード',

	// N
	'navigation' => 'ナビゲーション',
	'nom' => 'お名前',
	'nouveautes' => '最新刊',
	'nouveautes_web' => 'ウェブに関する最新刊',
	'nouveaux_articles' => '新しい記事',
	'nouvelles_breves' => '新しいニュース',

	// P
	'page_precedente' => '前のページ',
	'page_suivante' => '次のページ',
	'par_auteur' => '著者：',
	'participer_site' => 'サインアップすると、サイトにご自分の記事を書くことが出来ます。申し込みしてから、管理エリアへのアクセスコードがメールで届きます。',
	'plan_site' => 'サイトマップ',
	'popularite' => '人気',
	'poster_message' => 'メッセージを投稿する',
	'proposer_site' => '追加するサイトを提案できるセクション：',

	// R
	'repondre_article' => 'この記事に返信する',
	'repondre_breve' => 'このニュースに返信する',
	'resultats_recherche' => '検索結果',
	'retour_debut_forums' => 'フォーラムの最初のページに戻る',
	'rubrique' => 'セクション',
	'rubriques' => 'セクション',

	// S
	'signatures_petition' => '署名',
	'site_realise_avec_spip' => 'SPIPで創造されたサイトです',
	'sites_web' => 'ウェブサイト',
	'sous_rubriques' => 'サブセクション',
	'spam' => '迷惑メール',
	'suite' => '次へ',
	'sur_web' => 'ウェブ上',
	'syndiquer_rubrique' => 'このセクションを供給する',
	'syndiquer_site' => '全サイトを供給する',

	// T
	'texte_lettre_information' => 'サイトのニュースレター',
	'texte_lettre_information_2' => '最新刊をまとめるニュースレター',

	// V
	'ver_imprimer' => '印刷用のバージョン',
	'voir_en_ligne' => 'オンラインで見る',
	'voir_squelette' => 'ページのテンプレートを見る'
);

==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'ホーム',
	'article' => '記事',
	'articles' => '記事',
	'articles_auteur' => 'この著者の記事',
	'articles_populaires' => '人気のある記事',
	'articles_rubrique' => 'このセクションにある記事',
	'aucun_article' => 'このアドレスに記事はありません',
	'aucun_auteur' => 'このアドレスに著者はいません',
	'aucun_site' => 'このアドレスにサイトはありません',
	'aucune_breve' => 'このアドレスにニュースはありません',
	'aucune_rubrique' => 'このアドレスにセクションはありません',
	'auteur' => '著者',
	'autres' => 'その他',
	'autres_breves' => '他のニュース',
	'autres_groupes_mots_clefs' => 'キーワードの他のグループ',
	'autres_sites' => '他のサイト',

	// B
	'bonjour' => 'こんにちは',

	// C
	'commenter_site' => 'このサイトについてコメントして下さい',
	'contact' => '連絡先',
	'copie_document_impossible' => 'ファイルのコーピは不可能です',

	// D
	'date' => '日付',
	'dernier_ajout' => '最新の追加',
	'dernieres_breves' => '最新のニュース',
	'derniers_articles' => '最新の記事',
	'derniers_commentaires' => '最新のコメント',
	'derniers_messages_forum' => 'フォーラムで投稿された最新のメッセージ',

	// E
	'edition_mode_texte' => 'テキストモード編集',
	'en_reponse' => '返事として：',
	'en_resume' => 'まとめとして',
	'envoyer_message' => 'メッセージを送る',
	'espace_prive' => '管理エリア',

	// F
	'formats_acceptes' => '受け入れるファイルのフォーマット: @formats@です。',

	// H
	'hierarchie_site' => 'サイトの階層',

	// J
	'jours' => '日付',

	// L
	'lien_connecter' => 'ログイン',

	// M
	'meme_auteur' => '同じ著者',
	'meme_rubrique' => '同じセクションの中で',
	'memes_auteurs' => '同じ著者',
	'message' => 'フォーラムのメッセージ',
	'messages_forum' => 'フォーラムのメッセージ',
	'messages_recents' => '最新のフォーラムのメッセージ',
	'mots_clef' => 'キーワード',
	'mots_clefs' => 'キーワード',
	'mots_clefs_meme_groupe' => '同じグループのキーワード',

	// N
	'navigation' => 'ナビゲーション',
	'nom' => 'お名前',
	'nouveautes' => '最新刊',
	'nouveautes_web' => 'ウェブに関する最新刊',
	'nouveaux_articles' => '新しい記事',
	'nouvelles_breves' => '新しいニュース',

	// P
	'page_precedente' => '前のページ',
	'page_suivante' => '次のページ',
	'par_auteur' => '著者：',
	'participer_site' => 'サインアップすると、サイトにご自分の記事を書くことが出来ます。申し込みしてから、管理エリアへのアクセスコードがメールで届きます。',
	'plan_site' => 'サイトマップ',
	'popularite' => '人気',
	'poster_message' => 'メッセージを投稿する',
	'proposer_site' => '追加するサイトを提案できるセクション：',

	// R
	'repondre_article' => 'この記事に返信する',
	'repondre_breve' => 'このニュースに返信する',
	'resultats_recherche' => '検索結果',
	'retour_debut_forums' => 'フォーラムの最初のページに戻る',
	'rss_abonnement' => '以下のURLをアグリゲーターにコピーしてください。',
	'rss_abonnement_titre' => '購読してください。',
	'rss_abonnement_titre_page' => '購読してください。',
	'rss_explication' => 'RSSフィードは、サイトの更新情報を収集するものです。投稿やコメントの内容やその抜粋、全文へのリンクなどの情報を提供します。このフィードは、RSSアグリゲーターで読み込むことを想定しています。',
	'rss_explication_titre' => 'RSSフィードとは？',
	'rubrique' => 'セクション',
	'rubriques' => 'セクション',

	// S
	'signatures_petition' => '署名',
	'site_realise_avec_spip' => 'SPIPで創造されたサイトです',
	'sites_web' => 'ウェブサイト',
	'sous_rubriques' => 'サブセクション',
	'spam' => '迷惑メール',
	'suite' => '次へ',
	'sur_web' => 'ウェブ上',
	'syndiquer_rubrique' => 'このセクションを供給する',
	'syndiquer_site' => '全サイトを供給する',

	// T
	'texte_lettre_information' => 'サイトのニュースレター',
	'texte_lettre_information_2' => '最新刊をまとめるニュースレター',

	// V
	'ver_imprimer' => '印刷用のバージョン',
	'voir_en_ligne' => 'オンラインで見る',
	'voir_squelette' => 'ページのテンプレートを見る'
);
